@@ -947,7 +947,7 @@ class Graph(object):
         usetimer = nnodes is None and rev is None
         if usetimer:
             if os.name == "nt":
-                timer = time.clock
+                timer = time.clock  # pytype: disable=module-attr
             else:
                 timer = time.time
             startsec = timer()
