@@ -1203,7 +1203,7 @@ class RepoWidget(QWidget):
             showoutput = info.get('showoutput', False)
             label = info.get('label', name)
             icon = info.get('icon', 'tools-spanner-hammer')
-            enable = info.get('enable', 'istrue').lower()
+            enable = info.get('enable', 'istrue').lower()  # pytype: disable=attribute-error
             if enable in _ENABLE_MENU_FUNCS:
                 enable = _ENABLE_MENU_FUNCS[enable]
             else:
